stringtools.is_snake_case_file_name_with_extension
==================================================

.. autofunction:: abjad.tools.stringtools.is_snake_case_file_name_with_extension.is_snake_case_file_name_with_extension
